@@ -1,7 +1,21 @@
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
-######################### 
+# To run: perl -Mblib test.pl
+
+##
+## Check for old log file.
+##
+my $logfile = '/tmp/UnixODBC.log';
+my $answer;
+if ( -f $logfile ) {
+    print "Old log file $logfile exists.  Delete (Y/n)?";
+    $answer = getc(STDIN);
+    `rm -f $logfile` if $answer !~ /n/i;
+    print "\n";
+}
+
+######################### We start with some black magic to print on failure.
 
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
@@ -12,7 +26,7 @@ use UnixODBC ':all';
 $loaded = 1;
 print "ok 1\n";
 
-######################### 
+######################### End of black magic.
 
 use Devel::Peek;
 
@@ -24,21 +38,9 @@ my $programname = 'test.pl';
 
 # Connect parameters
 my $DSN="Gutenberg Catalog";
-#
-#  Change to the DBMS user name and password.  For PostgreSQL after
-#  installation, "postgres," should work.  For MySQL, "root" should
-#  work after installation, or start 
-#  mysqld_safe with --skip-grant-tables.
-#
-my $UserName="postgres";
+my $UserName="";
 my $PassWord="";
 
-#
-#  Uncomment this line if you are using the unixODBC 
-#  postgresql driver.
-#
-# $SIG{PIPE} = sub { print "SIGPIPE: $!\n" };
-
 # Variables for SQLGetDataSources
 my ($dsnname,$drivername,$messagelength1, $messagelength2);
 
@@ -70,11 +72,13 @@ my $datafence = '-' x 20;
 
 # Queries for test table
 
+&UnixODBC::dm_log_open ($programname, $logfile);
+
 $SIG{PIPE} = sub{print "SIGPIPE: ". $!."\n"};
 
-print "======================================================\n";
-print "Handle Allocation, Data Sources, and ODBC Version.\n";
-print "======================================================\n";
+## 
+## Handle allocation, Data sources, and ODBC Version
+##
 
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
@@ -145,7 +149,7 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_DBC, $cnh);
 }
 
-print "Get Data Sources... ";
+print "Get Data Sources... \n";
 $r = &UnixODBC::SQLDataSources ( $evh, $SQL_FETCH_FIRST, $dsnname, 255, 
 				 $messagelength1, $drivername, 255, 
 				 $messagelength2 );
@@ -180,13 +184,13 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close;
+
 ##
 ## Connection to DSN
 ##
 
-print "======================================================\n";
-print "Connect to DSN\n";
-print "======================================================\n";
+&UnixODBC::dm_log_open ($programname, $logfile);
 
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
@@ -301,13 +305,14 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
 ##
 ## SQL Query and Fetch
 ##
 
-print "======================================================\n";
-print "SQL Query and Data Fetch.\n";
-print "======================================================\n";
+&UnixODBC::dm_log_open($programname, $logfile);
+
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
 if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
@@ -470,12 +475,13 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
 ###
 ### Get info for data types
 ###
-print "======================================================\n";
-print "Data Types Info.\n";
-print "======================================================\n";
+
+&UnixODBC::dm_log_open($programname, $logfile);
 
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
@@ -587,13 +593,14 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
 ##
 ## Execute and fetch with prepared SQL query.
 ##
 
-print "======================================================\n";
-print "Prepared Query and Data Fetch\n";
-print "======================================================\n";
+&UnixODBC::dm_log_open($programname, $logfile);
+
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
 if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
@@ -787,13 +794,14 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
 ##
 ## Translate SQL statement
 ##
 
-print "======================================================\n";
-print "Translate SQL Statement\n";
-print "======================================================\n";
+&UnixODBC::dm_log_open($programname, $logfile);
+
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV,
 				 $SQL_NULL_HANDLE, $evh);
@@ -857,7 +865,7 @@ print "Translate SQL statement... ";
 $r = &UnixODBC::SQLNativeSql ($cnh, $query, length ($query), $rbuf, 
 			      255, $mlen);
 print "\n$datafence\n";
-print "Statement: \"$rbuf\" Length: \"$mlen\"\n";
+print "$rbuf, $mlen\n";
 print "$datafence\n";
 if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     print "ok 74\n";
@@ -893,13 +901,14 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
 ##
 ## SQL Query and FetchScroll
 ##
 
-print "======================================================\n";
-print "SQL Query and FetchScroll\n";
-print "======================================================\n";
+&UnixODBC::dm_log_open($programname, $logfile);
+
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
 if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
@@ -1032,10 +1041,9 @@ while (1) {
     $r = &UnixODBC::SQLGetData ($sth, 5, $SQL_C_CHAR, $title, 255, $mlen);
     print "$title\n";
 }
-print "$datafence\n";
 
 print "Set position... ";
-$r = &UnixODBC::SQLSetPos ($sth, 1, $SQL_UPDATE, $SQL_LOCK_UNLOCK);
+$r = &UnixODBC::SQLSetPos ($sth, 1, $SQL_POSITION, $SQL_LOCK_NO_CHANGE);
 if ($r==$SQL_SUCCESS) {
     print "ok 91\n";
 } else {
@@ -1072,7 +1080,7 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
 
 print "Get column names...";
 $r = &UnixODBC::SQLColumns ($sth, '', 0, '', 0, 
-			    'titles', $SQL_NTS,
+			    'titles', length ('titles'),
 			    '', 0);
 if ($r==$SQL_SUCCESS) {
     print "ok 95\n";
@@ -1084,7 +1092,7 @@ while (1) {
     $r = &UnixODBC::SQLFetch ($sth);
     last if $r == $SQL_NO_DATA;
     foreach my $cn (1..4) {
-	$r=&UnixODBC::SQLGetData ($sth, $cn, $SQL_C_CHAR, $rbuf, 4096, $mlen);
+	$r=&UnixODBC::SQLGetData ($sth, $cn, $SQL_C_CHAR, $rbuf, 255, $mlen);
 	print "$rbuf ";
     }
     print "\n";
@@ -1115,7 +1123,7 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
 }
 
 print "Get primary keys... ";
-$r = &UnixODBC::SQLPrimaryKeys ($sth, '', 0, '', 0, 'titles', $SQL_NTS);
+$r = &UnixODBC::SQLPrimaryKeys ($sth, '', 0, '', 0, 'titles', 6);
 if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
     print "ok 99 \n";
 } else {
@@ -1169,8 +1177,9 @@ if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
 }
 
 print "Get column privileges...";
-$r = &UnixODBC::SQLColumnPrivileges ($sth, '', 0, '', 0, 'titles', $SQL_NTS,
-				     'id_no', $SQL_NTS);
+$r = &UnixODBC::SQLColumnPrivileges ($sth, '', 0, '', 0, 
+				     'titles', length ('titles'),
+				     'id_no', length ('id_no'));
 if ($r==$SQL_SUCCESS) {
     print "ok 105\n";
 } else {
@@ -1360,6 +1369,10 @@ if ($r==$SQL_SUCCESS) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
+&UnixODBC::dm_log_open($programname, $logfile);
+
 print "Allocate environment handle... "; 
 $r = &UnixODBC::SQLAllocHandle ($SQL_HANDLE_ENV, $SQL_NULL_HANDLE, $evh);
 if (($r==$SQL_SUCCESS)||($r==$SQL_NO_DATA)) {
@@ -1483,12 +1496,14 @@ if ($r==$SQL_SUCCESS) {
     &getdiagrec ($SQL_HANDLE_ENV, $evh);
 }
 
+&UnixODBC::dm_log_close();
+
 sub getdiagrec {
     my ($handle_type, $handle) = @_;
     my ($sqlstate, $native, $message_text);
     print 'SQLGetDiagRec: ';
     $r = &UnixODBC::SQLGetDiagRec ($handle_type, $handle, 1, $sqlstate,
-				   $native, $message_text, 4096,
+				   $native, $message_text, 255,
 				   $mlen);
     if ($r == $SQL_NO_DATA) { 
 	print "result \= SQL_NO_DATA\n";
